pager

# XMLRésuméLibrary: User Guide

pageNums | Element Reference | para

## Name

pager — A pager telephone number

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `pager` element contains a telephone number that can be used to connect to a pager. The phone number is not required to be in a specific format. (See `phone` for examples of numbers.)

### Parents

`pager` may be contained in these elements: `contact`

## See Also

`email`, `fax`, `phone`.

## Examples

    <pager>456-145-4468</pager>

    <pager>736.272.4673 x 235</pager>

pageNums | Element Reference | para